==> jc-1.4.0.tar.gz: javax/accessibility/AccessibleRelation.h <==
// public class javax.accessibility.AccessibleRelation

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 31af68d307de0dce javax_accessibility_AccessibleBundle
// @dep_class 2e4711b0cceabf89 javax_accessibility_AccessibleRelation

// header file dependencies
// @dep_header javax_accessibility_AccessibleBundle

#include "javax/accessibility/AccessibleBundle.h"

#ifndef _JC_javax_accessibility_AccessibleRelation_H_
#define _JC_javax_accessibility_AccessibleRelation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_accessibility_AccessibleRelation$sub_refs	_jc_javax_accessibility_AccessibleRelation$sub_refs;
typedef struct _jc_javax_accessibility_AccessibleRelation$sub_nonrefs	_jc_javax_accessibility_AccessibleRelation$sub_nonrefs;
typedef struct _jc_javax_accessibility_AccessibleRelation$refs	_jc_javax_accessibility_AccessibleRelation$refs;
typedef struct _jc_javax_accessibility_AccessibleRelation$nonrefs	_jc_javax_accessibility_AccessibleRelation$nonrefs;
typedef struct _jc_javax_accessibility_AccessibleRelation$object	_jc_javax_accessibility_AccessibleRelation$object;

typedef struct _jc_javax_accessibility_AccessibleRelation$fields_struct	_jc_javax_accessibility_AccessibleRelation$fields_struct;
typedef const struct _jc_javax_accessibility_AccessibleRelation$vmethods	_jc_javax_accessibility_AccessibleRelation$vmethods;
typedef const struct _jc_javax_accessibility_AccessibleRelation$vtable	_jc_javax_accessibility_AccessibleRelation$vtable;
typedef const struct _jc_javax_accessibility_AccessibleRelation$vtype	_jc_javax_accessibility_AccessibleRelation$vtype;

// Class fields structure
struct _jc_javax_accessibility_AccessibleRelation$fields_struct {
	struct _jc_java_lang_String$object	*CONTROLLED__5fBY;
	struct _jc_java_lang_String$object	*CONTROLLED__5fBY__5fPROPERTY;
	struct _jc_java_lang_String$object	*CONTROLLER__5fFOR;
	struct _jc_java_lang_String$object	*CONTROLLER__5fFOR__5fPROPERTY;
	_jc_object_array	*EMPTY__5fTARGETS;
	struct _jc_java_lang_String$object	*LABELED__5fBY;
	struct _jc_java_lang_String$object	*LABELED__5fBY__5fPROPERTY;
	struct _jc_java_lang_String$object	*LABEL__5fFOR;
	struct _jc_java_lang_String$object	*LABEL__5fFOR__5fPROPERTY;
	struct _jc_java_lang_String$object	*MEMBER__5fOF;
	struct _jc_java_lang_String$object	*MEMBER__5fOF__5fPROPERTY;
};
extern _jc_javax_accessibility_AccessibleRelation$fields_struct _jc_javax_accessibility_AccessibleRelation$class_fields;

// Constructors
extern void _jc_javax_accessibility_AccessibleRelation$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_accessibility_AccessibleRelation$method$_init$5cd68f4fce864f30(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);
extern void _jc_javax_accessibility_AccessibleRelation$method$_init$1673a34f53b5c3b8(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_accessibility_AccessibleRelation$method$getKey$34fe8b840403bb48(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *);
extern _jc_object_array *_jc_javax_accessibility_AccessibleRelation$method$getTarget$8766deb312fb08f9(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *);
extern void _jc_javax_accessibility_AccessibleRelation$method$setTarget$6e909b38721c1250(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_java_lang_Object$object *);
extern void _jc_javax_accessibility_AccessibleRelation$method$setTarget$a9213b0432de2297(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_javax_accessibility_AccessibleRelation$method_info$getKey$34fe8b840403bb48;
extern _jc_method _jc_javax_accessibility_AccessibleRelation$method_info$getTarget$8766deb312fb08f9;
extern _jc_method _jc_javax_accessibility_AccessibleRelation$method_info$setTarget$6e909b38721c1250;
extern _jc_method _jc_javax_accessibility_AccessibleRelation$method_info$setTarget$a9213b0432de2297;

// Static methods
extern void _jc_javax_accessibility_AccessibleRelation$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_accessibility_AccessibleRelation$vmethods {
	struct _jc_java_lang_String$object	*(*getKey$34fe8b840403bb48)(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *);
	_jc_object_array	*(*getTarget$8766deb312fb08f9)(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *);
	void	(*setTarget$6e909b38721c1250)(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_java_lang_Object$object *);
	void	(*setTarget$a9213b0432de2297)(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_javax_accessibility_AccessibleRelation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleBundle$vmethods	javax_accessibility_AccessibleBundle;
	_jc_javax_accessibility_AccessibleRelation$vmethods	javax_accessibility_AccessibleRelation;
};

// Vtype
struct _jc_javax_accessibility_AccessibleRelation$vtype {
	_jc_type			type;
	_jc_javax_accessibility_AccessibleRelation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleRelation$sub_refs {
	_jc_object_array	*targets;
};

// Reference instance fields (object)
struct _jc_javax_accessibility_AccessibleRelation$refs {
    _jc_javax_accessibility_AccessibleRelation$sub_refs	javax_accessibility_AccessibleRelation;
    _jc_javax_accessibility_AccessibleBundle$sub_refs	javax_accessibility_AccessibleBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleRelation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_accessibility_AccessibleRelation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleBundle$sub_nonrefs	javax_accessibility_AccessibleBundle;
    _jc_javax_accessibility_AccessibleRelation$sub_nonrefs	javax_accessibility_AccessibleRelation;
};

// Object instance structure
struct _jc_javax_accessibility_AccessibleRelation$object {
	_jc_javax_accessibility_AccessibleRelation$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_accessibility_AccessibleRelation$vtype	*vtype;
	_jc_javax_accessibility_AccessibleRelation$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_accessibility_AccessibleRelation$vtype _jc_javax_accessibility_AccessibleRelation$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_accessibility_AccessibleRelation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_accessibility_AccessibleRelation$class_object;

#endif	/* _JC_javax_accessibility_AccessibleRelation_H_ */

==> jc-1.4.5.tar.gz: javax/accessibility/AccessibleRelation.h <==
// public class javax.accessibility.AccessibleRelation

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 31af68d307de0dce javax_accessibility_AccessibleBundle
// @dep_class 2e4711b0cceabf89 javax_accessibility_AccessibleRelation

// header file dependencies
// @dep_header javax_accessibility_AccessibleBundle

#include "javax/accessibility/AccessibleBundle.h"

#ifndef _JC_javax_accessibility_AccessibleRelation_H_
#define _JC_javax_accessibility_AccessibleRelation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_accessibility_AccessibleRelation$sub_refs	_jc_javax_accessibility_AccessibleRelation$sub_refs;
typedef struct _jc_javax_accessibility_AccessibleRelation$sub_nonrefs	_jc_javax_accessibility_AccessibleRelation$sub_nonrefs;
typedef struct _jc_javax_accessibility_AccessibleRelation$refs	_jc_javax_accessibility_AccessibleRelation$refs;
typedef struct _jc_javax_accessibility_AccessibleRelation$nonrefs	_jc_javax_accessibility_AccessibleRelation$nonrefs;
typedef struct _jc_javax_accessibility_AccessibleRelation$object	_jc_javax_accessibility_AccessibleRelation$object;

typedef struct _jc_javax_accessibility_AccessibleRelation$fields_struct	_jc_javax_accessibility_AccessibleRelation$fields_struct;
typedef const struct _jc_javax_accessibility_AccessibleRelation$vmethods	_jc_javax_accessibility_AccessibleRelation$vmethods;
typedef const struct _jc_javax_accessibility_AccessibleRelation$vtable	_jc_javax_accessibility_AccessibleRelation$vtable;
typedef const struct _jc_javax_accessibility_AccessibleRelation$vtype	_jc_javax_accessibility_AccessibleRelation$vtype;

// Class fields structure
struct _jc_javax_accessibility_AccessibleRelation$fields_struct {
	struct _jc_java_lang_String$object	*CONTROLLED__5fBY;
	struct _jc_java_lang_String$object	*CONTROLLED__5fBY__5fPROPERTY;
	struct _jc_java_lang_String$object	*CONTROLLER__5fFOR;
	struct _jc_java_lang_String$object	*CONTROLLER__5fFOR__5fPROPERTY;
	_jc_object_array	*EMPTY__5fTARGETS;
	struct _jc_java_lang_String$object	*LABELED__5fBY;
	struct _jc_java_lang_String$object	*LABELED__5fBY__5fPROPERTY;
	struct _jc_java_lang_String$object	*LABEL__5fFOR;
	struct _jc_java_lang_String$object	*LABEL__5fFOR__5fPROPERTY;
	struct _jc_java_lang_String$object	*MEMBER__5fOF;
	struct _jc_java_lang_String$object	*MEMBER__5fOF__5fPROPERTY;
};
extern _jc_javax_accessibility_AccessibleRelation$fields_struct _jc_javax_accessibility_AccessibleRelation$class_fields;

// Constructors
extern void _jc_javax_accessibility_AccessibleRelation$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_accessibility_AccessibleRelation$method$_init$5cd68f4fce864f30(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_javax_accessibility_AccessibleRelation$method$_init$1673a34f53b5c3b8(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_accessibility_AccessibleRelation$method$getKey$34fe8b840403bb48(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_accessibility_AccessibleRelation$method$getTarget$8766deb312fb08f9(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *) _JC_JCNI_ATTR;
extern void _jc_javax_accessibility_AccessibleRelation$method$setTarget$6e909b38721c1250(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_javax_accessibility_AccessibleRelation$method$setTarget$a9213b0432de2297(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_accessibility_AccessibleRelation$method_info$getKey$34fe8b840403bb48;
extern _jc_method _jc_javax_accessibility_AccessibleRelation$method_info$getTarget$8766deb312fb08f9;
extern _jc_method _jc_javax_accessibility_AccessibleRelation$method_info$setTarget$6e909b38721c1250;
extern _jc_method _jc_javax_accessibility_AccessibleRelation$method_info$setTarget$a9213b0432de2297;

// Static methods
extern void _jc_javax_accessibility_AccessibleRelation$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_accessibility_AccessibleRelation$vmethods {
	struct _jc_java_lang_String$object	*(*getKey$34fe8b840403bb48)(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getTarget$8766deb312fb08f9)(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *) _JC_JCNI_ATTR;
	void	(*setTarget$6e909b38721c1250)(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*setTarget$a9213b0432de2297)(_jc_env *, struct _jc_javax_accessibility_AccessibleRelation$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_accessibility_AccessibleRelation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleBundle$vmethods	javax_accessibility_AccessibleBundle;
	_jc_javax_accessibility_AccessibleRelation$vmethods	javax_accessibility_AccessibleRelation;
};

// Vtype
struct _jc_javax_accessibility_AccessibleRelation$vtype {
	_jc_type			type;
	_jc_javax_accessibility_AccessibleRelation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleRelation$sub_refs {
	_jc_object_array	*targets;
};

// Reference instance fields (object)
struct _jc_javax_accessibility_AccessibleRelation$refs {
    _jc_javax_accessibility_AccessibleRelation$sub_refs	javax_accessibility_AccessibleRelation;
    _jc_javax_accessibility_AccessibleBundle$sub_refs	javax_accessibility_AccessibleBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleRelation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_accessibility_AccessibleRelation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleBundle$sub_nonrefs	javax_accessibility_AccessibleBundle;
    _jc_javax_accessibility_AccessibleRelation$sub_nonrefs	javax_accessibility_AccessibleRelation;
};

// Object instance structure
struct _jc_javax_accessibility_AccessibleRelation$object {
	_jc_javax_accessibility_AccessibleRelation$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_accessibility_AccessibleRelation$vtype	*vtype;
	_jc_javax_accessibility_AccessibleRelation$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_accessibility_AccessibleRelation$vtype _jc_javax_accessibility_AccessibleRelation$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_accessibility_AccessibleRelation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_accessibility_AccessibleRelation$class_object;

#endif	/* _JC_javax_accessibility_AccessibleRelation_H_ */
